@@ -41,7 +41,7 @@ jomo1con<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1cov.prior=NU
   opost<-matrix(0,nrow(l1cov.start),ncol(l1cov.start))
   meanobs<-colMeans(Y,na.rm=TRUE)
   for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=meanobs[j]
-  .Call("jomo1con", Y, Yimp, Yimp2, X,betait,bpost,covit, opost, nburn, l1cov.prior,out.iter, PACKAGE = "jomo")
+  .Call("jomo1conC", Y, Yimp, Yimp2, X,betait,bpost,covit, opost, nburn, l1cov.prior,out.iter, PACKAGE = "jomo")
   #betapost[,,1]=bpost
   #omegapost[,,1]=opost
   bpost<-matrix(0,nrow(beta.start),ncol(beta.start))
@@ -54,7 +54,7 @@ jomo1con<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1cov.prior=NU
     imp[(i*nrow(X)+1):((i+1)*nrow(X)),(ncol(Y)+1):(ncol(Y)+ncol(X))]=X
     imp[(i*nrow(X)+1):((i+1)*nrow(X)), (ncol(Y)+ncol(X)+1)]=i
     imp[(i*nrow(X)+1):((i+1)*nrow(X)), (ncol(Y)+ncol(X)+2)]=c(1:nrow(Y))
-    .Call("jomo1con", Y, Yimp, Yimp2, X,betait,bpost,covit, opost, nbetween, l1cov.prior,out.iter, PACKAGE = "jomo")
+    .Call("jomo1conC", Y, Yimp, Yimp2, X,betait,bpost,covit, opost, nbetween, l1cov.prior,out.iter, PACKAGE = "jomo")
     betapost[,,(i-1)]=bpost
     omegapost[,,(i-1)]=opost
     bpost<-matrix(0,nrow(beta.start),ncol(beta.start))
